==> org.eclipse.jgit.ssh.apache.source_5.2.0.201812061821-r.jar: org/eclipse/jgit/transport/sshd/DefaultProxyDataFactory.java <==
/*
 * Copyright (C) 2018, Thomas Wolf <thomas.wolf@paranor.ch>
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.eclipse.jgit.transport.sshd;

import java.net.InetSocketAddress;
import java.net.Proxy;
import java.net.ProxySelector;
import java.net.SocketAddress;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.List;

/**
 * A default implementation of a {@link ProxyDataFactory} based on the standard
 * {@link java.net.ProxySelector}.
 *
 * @since 5.2
 */
public class DefaultProxyDataFactory implements ProxyDataFactory {

	@Override
	public ProxyData get(InetSocketAddress remoteAddress) {
		try {
			List<Proxy> proxies = ProxySelector.getDefault()
					.select(new URI(Proxy.Type.SOCKS.name(),
							"//" + remoteAddress.getHostString(), null)); //$NON-NLS-1$
			ProxyData data = getData(proxies, Proxy.Type.SOCKS);
			if (data == null) {
				proxies = ProxySelector.getDefault()
						.select(new URI(Proxy.Type.HTTP.name(),
								"//" + remoteAddress.getHostString(), //$NON-NLS-1$
								null));
				data = getData(proxies, Proxy.Type.HTTP);
			}
			return data;
		} catch (URISyntaxException e) {
			return null;
		}
	}

	private ProxyData getData(List<Proxy> proxies, Proxy.Type type) {
		Proxy proxy = proxies.stream().filter(p -> type == p.type()).findFirst()
				.orElse(null);
		if (proxy == null) {
			return null;
		}
		SocketAddress address = proxy.address();
		if (!(address instanceof InetSocketAddress)) {
			return null;
		}
		switch (type) {
		case HTTP:
			return new ProxyData(proxy);
		case SOCKS:
			return new ProxyData(proxy);
		default:
			return null;
		}
	}
}

==> org.eclipse.jgit.ssh.apache.source_5.5.0.201909110433-r.jar: org/eclipse/jgit/transport/sshd/DefaultProxyDataFactory.java <==
/*
 * Copyright (C) 2018, Thomas Wolf <thomas.wolf@paranor.ch>
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.eclipse.jgit.transport.sshd;

import java.net.InetSocketAddress;
import java.net.Proxy;
import java.net.ProxySelector;
import java.net.SocketAddress;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.List;

/**
 * A default implementation of a {@link ProxyDataFactory} based on the standard
 * {@link java.net.ProxySelector}.
 *
 * @since 5.2
 */
public class DefaultProxyDataFactory implements ProxyDataFactory {

	@Override
	public ProxyData get(InetSocketAddress remoteAddress) {
		try {
			List<Proxy> proxies = ProxySelector.getDefault()
					.select(new URI(
							"socket://" + remoteAddress.getHostString())); //$NON-NLS-1$
			ProxyData data = getData(proxies, Proxy.Type.SOCKS);
			if (data == null) {
				proxies = ProxySelector.getDefault()
						.select(new URI(Proxy.Type.HTTP.name(),
								"//" + remoteAddress.getHostString(), //$NON-NLS-1$
								null));
				data = getData(proxies, Proxy.Type.HTTP);
			}
			return data;
		} catch (URISyntaxException e) {
			return null;
		}
	}

	private ProxyData getData(List<Proxy> proxies, Proxy.Type type) {
		Proxy proxy = proxies.stream().filter(p -> type == p.type()).findFirst()
				.orElse(null);
		if (proxy == null) {
			return null;
		}
		SocketAddress address = proxy.address();
		if (!(address instanceof InetSocketAddress)) {
			return null;
		}
		switch (type) {
		case HTTP:
			return new ProxyData(proxy);
		case SOCKS:
			return new ProxyData(proxy);
		default:
			return null;
		}
	}
}
